@@ -1,12 +1,12 @@
 from copy import deepcopy
 
 import yaml
-from readerwriterlock.rwlock import RWLockFairD
+from readerwriterlock.rwlock import RWLockReadD
 
 
 class Config(object):
     def __init__(self, path: str):
-        self.__lock = RWLockFairD()
+        self.__lock = RWLockReadD()
         self.__conf = None
         self.__path = path
         self.reload_config()
